CursorIcon

Enum CursorIcon 

#[non_exhaustive]
pub enum CursorIcon { Normal, Crosshair, PointingHand, }
Suggested mouse pointer appearance for a given Cursor state.

Obtain this from Session::cursor_icon().

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Normal

The platform’s default appearance; often an arrowhead.



Crosshair

A crosshair “┼”, suggesting aiming/positioning/selecting.



PointingHand

A hand with finger extended as if to press a button.