FrameClock

Struct FrameClock 

pub struct FrameClock { /* private fields */ }
Algorithm for deciding how to execute simulation and rendering frames. Platform-independent; does not consult any clocks, only makes decisions given the provided information.

Implementations

Source

impl FrameClock

pub fn new(schedule: TickSchedule) -> Self

Constructs a new FrameClock.

This operation is independent of the system clock.

Source

impl FrameClock

pub fn advance_to(&mut self, instant: Instant)

Advance the clock using a source of absolute time.

This cannot be meaningfully used in combination with FrameClock::request_frame() or FrameClock::advance_by().

pub fn advance_by(&mut self, duration: Duration)

Advance the clock using a source of relative time.

pub fn request_frame(&mut self, time_since_last_frame: Duration) -> bool

Reacts to a callback from the environment requesting drawing a frame ASAP if we’re going to (i.e. requestAnimationFrame on the web). Drives the simulation clock based on this input (it will not advance if no requests are made).

Returns whether a frame should actually be rendered now. The caller should also consult FrameClock::should_step() afterward to schedule game state steps.

This cannot be meaningfully used in combination with FrameClock::advance_to().

pub fn next_step_or_draw_time(&self) -> Option<Instant>

Returns the next time at which FrameClock::should_step(), and then FrameClock::should_draw(), should be consulted.

FrameClock::advance_to() must have previously been called to give an absolute time reference.

pub fn should_draw(&self) -> bool

Indicates whether a new frame should be drawn, given the amount of time that this FrameClock has been informed has passed.

When a frame is drawn, FrameClock::did_draw] must be called; otherwise, this will always return true.

pub fn did_draw(&mut self)

Informs the FrameClock that a frame was just drawn.

pub fn should_step(&self) -> bool

Indicates whether Universe::step() should be performed, given the amount of time that this FrameClock has been informed has passed.

When a step is performd, FrameClock::did_step must be called; otherwise, this will always return true.

pub fn did_step(&mut self, schedule: TickSchedule)

Informs the FrameClock that a step was just performed.

The caller must also provide an updated schedule, in case it has changed.