SessionBuilder

Struct SessionBuilder 

pub struct SessionBuilder { /* private fields */ }
Builder for providing the configuration of a new Session.

Implementations

Source

impl SessionBuilder

pub async fn build(self) -> Session

Create the Session with configuration from this builder.

This is an async function for the sake of cancellation and optional cooperative multitasking, while constructing the initial state. It may safely be blocked on from a synchronous context.

pub fn ui(self, viewport: DynSource<Viewport>) -> Self

Enable graphical user interface.

Requires knowing the expected viewport so that UI can be laid out to fit the aspect ratio.

If this is not called, then the session will simulate a world but not present any controls for it other than those provided directly by the InputProcessor.

pub fn fullscreen( self, state: DynSource<Option<bool>>, setter: Option<Arc<dyn Fn(bool) + Send + Sync>>, ) -> Self

Enable awareness of whether the session is being displayed full-screen.

  • state should report the current state (true = is full screen). A None value means the state is unknown.
  • setter is a function which attempts to change the fullscreen state.
pub fn settings_from(self, settings: Settings) -> Self

Enable reading and writing user settings.

The session will get a new Settings object which inherits the given settings.

If this is not called, then the session will have all default settings, and they will not be persisted.

pub fn quit( self, quit_fn: Arc<dyn Fn() -> Result<QuitSucceeded, QuitCancelled> + Send + Sync>, ) -> Self

Enable a “quit”/“exit” command in the session’s user interface.

This does not cause the session to self-destruct; rather, the provided callback function should cause the session’s owner to stop presenting it to the user (and be dropped). It may also report that the quit was cancelled for whatever reason.