NotificationContent

Enum NotificationContent 

#[non_exhaustive]
pub enum NotificationContent { Progress { title: ArcStr, progress: ProgressBarState, part: ArcStr, }, }
User-visible contents of a Notification.

This value type is cheap to clone and comparing it compares the entire content.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Progress

Fields

title: ArcStr

The activity this is the progress of.

progress: ProgressBarState

The amount of progress.

part: ArcStr

The particular piece of the overall work that is currently being done (or was just finished, if that is all that is available).