#[non_exhaustive]pub enum InstallVuiError {
WidgetInitialization {
widget: Box<dyn WidgetController>,
error: Box<InstallVuiError>,
},
#[non_exhaustive] Conflict {
error: SpaceTransactionConflict,
},
OutOfBounds {
grant: LayoutGrant,
erroneous: GridAab,
widget: Arc<dyn Widget>,
},
#[non_exhaustive] ExecuteInstallation {
error: ExecuteError<SpaceTransaction>,
},
}Expand description
Errors that may arise from setting up LayoutTrees and Widgets and installing
them in a Space.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
WidgetInitialization
The widget failed to initialize for some reason.
Fields

widget: Box<dyn WidgetController>TODO: This should be Arc<dyn Widget> instead.
Or, if we come up with some way of giving widgets IDs, that.

error: Box<InstallVuiError>The error returned by WidgetController::initialize().
#[non_exhaustive]Conflict
A transaction conflict arose between two widgets or parts of a widget’s installation.
Fields
This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.

error: SpaceTransactionConflictOutOfBounds
The widget attempted to modify space outside its assigned bounds.
Fields

grant: LayoutGrantThe region given to the widget.
#[non_exhaustive]ExecuteInstallation
Installing the widget tree failed, because one of the widgets’ transactions failed. This usually indicates a bug in the widget implementation.
Fields
This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.

error: ExecuteError<SpaceTransaction>Trait Implementations
Sourceimpl Debug for InstallVuiError
impl Debug for InstallVuiError
Sourceimpl Display for InstallVuiError
impl Display for InstallVuiError
Sourceimpl Error for InstallVuiError
impl Error for InstallVuiError
Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0: use the Display impl or to_string()
Sourceimpl From<InstallVuiError> for InGenError
impl From<InstallVuiError> for InGenError
Sourcefn from(value: InstallVuiError) -> Self
fn from(value: InstallVuiError) -> Self
Converts to this type from the input type.