pub struct LayoutRequest {
pub minimum: GridSize,
}Expand description
Requested size and relative positioning of a widget or other thing occupying space, to be interpreted by a layout algorithm to choose the real position.
TODO: give this type and Layoutable better names
Fields
minimum: GridSizeThe minimum dimensions required, without which correct functionality is not possible.
Implementations
Sourceimpl LayoutRequest
impl LayoutRequest