TextBox

Struct TextBox 

pub struct TextBox { /* private fields */ }
Widget which draws Text that can change, to be used for textual content, or labels which change.

For text which does not change, use Label instead.

Implementations

Source

impl TextBox

pub fn dynamic_label( text_source: DynSource<ArcStr>, minimum_size: GridSize, ) -> Self

Constructs a TextBox that draws the given text, with the standard UI label font and no border.